/*
 * Copyright (c) 2016-2022 VMware, Inc. All Rights Reserved.
 * This software is released under MIT license.
 * The full license information can be found in LICENSE in the root directory of this project.
 */

import '@cds/core/textarea/register.js';
import { html } from 'lit';
import { getElementStorybookArgs, spreadProps } from '@cds/core/internal';

export default {
  title: 'Stories/Textarea',
  component: 'cds-textarea',
  parameters: {
    options: { showPanel: true },
    design: {
      type: 'figma',
      url: 'https://www.figma.com/file/v2mkhzKQdhECXOx8BElgdA/Clarity-UI-Library---light-2.2.0?node-id=0%3A861',
    },
  },
};

export function API(args: any) {
  return html`
    <cds-textarea ...="${spreadProps(getElementStorybookArgs(args))}">
      <label>textarea</label>
      <textarea></textarea>
      <cds-control-message .status=${args.status}>message text</cds-control-message>
    </cds-textarea>
  `;
}

/** @website */
export function textarea() {
  return html`
    <cds-textarea control-width="shrink">
      <label>textarea</label>
      <textarea></textarea>
      <cds-control-message>message text</cds-control-message>
    </cds-textarea>
  `;
}

/** @website */
export function vertical() {
  return html`
    <cds-form-group layout="vertical">
      <cds-textarea layout="vertical">
        <label>label</label>
        <textarea></textarea>
        <cds-control-message>message text</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="vertical">
        <label>disabled</label>
        <textarea disabled></textarea>
        <cds-control-message>disabled message</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="vertical" status="error">
        <label>error status</label>
        <textarea></textarea>
        <cds-control-message status="error">error message</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="vertical" status="success">
        <label>success status</label>
        <textarea></textarea>
        <cds-control-message status="success">success message</cds-control-message>
      </cds-textarea>
    </cds-form-group>
  `;
}

/** @website */
export function horizontal() {
  return html`
    <cds-form-group layout="horizontal">
      <cds-textarea layout="horizontal">
        <label>label</label>
        <textarea></textarea>
        <cds-control-message>message text</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="horizontal">
        <label>disabled</label>
        <textarea disabled></textarea>
        <cds-control-message>disabled message</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="horizontal" status="error">
        <label>error status</label>
        <textarea></textarea>
        <cds-control-message status="error">error message</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="horizontal" status="success">
        <label>success status</label>
        <textarea></textarea>
        <cds-control-message status="success">success message</cds-control-message>
      </cds-textarea>
    </cds-form-group>
  `;
}

/** @website */
export function compact() {
  return html`
    <cds-form-group layout="compact">
      <cds-textarea layout="compact">
        <label style="max-width: 180px">label</label>
        <textarea></textarea>
        <cds-control-message>message text</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="compact">
        <label>disabled</label>
        <textarea disabled></textarea>
        <cds-control-message>disabled message</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="compact" status="error">
        <label>error status</label>
        <textarea></textarea>
        <cds-control-message status="error">error message</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="compact" status="success">
        <label>success status</label>
        <textarea></textarea>
        <cds-control-message status="success">success message</cds-control-message>
      </cds-textarea>
    </cds-form-group>
  `;
}

export function darkTheme() {
  return html`
    <cds-form-group layout="horizontal" cds-theme="dark">
      <cds-textarea layout="horizontal">
        <label>label</label>
        <textarea></textarea>
        <cds-control-message>message text</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="horizontal">
        <label>disabled</label>
        <textarea disabled></textarea>
        <cds-control-message>disabled message</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="horizontal" status="error">
        <label>error status</label>
        <textarea></textarea>
        <cds-control-message status="error">error message</cds-control-message>
      </cds-textarea>

      <cds-textarea layout="horizontal" status="success">
        <label>success status</label>
        <textarea></textarea>
        <cds-control-message status="success">success message</cds-control-message>
      </cds-textarea>
    </cds-form-group>
  `;
}
